"use client";

import Link from "next/link";
import Image from "next/image";

import { motion } from "framer-motion";

import { BadgePlus, ChevronRight, Compass } from "lucide-react";

import { cn } from "@/lib/utils";
import { ANIMATION_EASE } from "@/lib/config";

import Marquee from "@/components/ui/marquee";
import { Button, buttonVariants } from "@/components/ui/button";
import { montserrat, spaceGrotesk } from "@/app/fonts";
import { PrivyInterface, usePrivy } from "@privy-io/react-auth";
import { Skeleton } from "@/components/ui/skeleton";

function HeroPill() {
  return (
    <motion.div
      initial={{ opacity: 0, y: -20 }}
      animate={{ opacity: 1, y: 0 }}
      transition={{ duration: 0.8, ease: ANIMATION_EASE }}
    >
      <Link
        href={"/explore"}
        className="flex w-auto items-center space-x-2 rounded-md bg-primary px-3 py-2 ring-1 ring-accent whitespace-pre"
      >
        <div className="w-fit rounded-md bg-accent  text-center text-xs font-medium text-primary sm:text-sm">
          <ChevronRight className="h-5 w-5" />
        </div>
        <p className="text-lg font-bold text-white sm:text-sm pr-2">
          Introducing soviro.ai
        </p>
      </Link>
    </motion.div>
  );
}

function HeroTitles() {
  return (
    <div className="flex w-full max-w-5xl flex-col space-y-4 overflow-hidden mt-12">
      <motion.h1
        className={cn(
          "text-center text-4xl font-medium leading-tight text-foreground sm:text-5xl md:text-6xl",
          spaceGrotesk.className
        )}
        initial={{ filter: "blur(10px)", opacity: 0, y: 50 }}
        animate={{ filter: "blur(0px)", opacity: 1, y: 0 }}
        transition={{
          duration: 1,
          staggerChildren: 0.2,
          ease: ANIMATION_EASE,
        }}
      >
        {["Seamless", "AI", "Integration", "for", "a", "Next-Gen", "SDK"].map(
          (text, index) => (
            <motion.span
              key={index}
              className="inline-block px-1 md:px-2 text-balance font-semibold"
              initial={{ opacity: 0, y: 20 }}
              animate={{ opacity: 1, y: 0 }}
              transition={{
                duration: 0.8,
                delay: index * 0.2,
                ease: ANIMATION_EASE,
              }}
            >
              {text}
            </motion.span>
          )
        )}
      </motion.h1>
      <motion.p
        className={cn(
          "mx-auto max-w-3xl text-center text-sm leading-7 text-muted-foreground sm:text-lg sm:leading-9 text-balance"
          // montserrat.className
        )}
        initial={{ opacity: 0, y: 20 }}
        animate={{ opacity: 1, y: 0 }}
        transition={{
          delay: 1.5,
          duration: 0.8,
          ease: ANIMATION_EASE,
        }}
      >
        Effortlessly build powerful AI agent workflows with minimal code,
        unlocking seamless automation and intelligent decision-making for
        complex tasks. Accelerate your development and drive efficiency with
        cutting-edge AI technology.
      </motion.p>
    </div>
  );
}

function HeroCTA({ privyAuth }: { privyAuth: PrivyInterface }) {
  const { ready, authenticated } = privyAuth;

  return (
    <>
      <motion.div
        className="mx-auto mt-12 pb-12 flex w-full max-w-2xl flex-col items-center justify-center space-y-4 sm:flex-row sm:space-x-4 sm:space-y-0"
        initial={{ opacity: 0, y: 20 }}
        animate={{ opacity: 1, y: 0 }}
        transition={{ delay: 1.75, duration: 0.8, ease: ANIMATION_EASE }}
      >
        {!ready ? (
          <Skeleton className="h-10 w-32" />
        ) : (
          <>
            {!authenticated ? (
              <Button disabled className="gap-2">
                <svg
                  width="24"
                  height="24"
                  viewBox="0 0 24 24"
                  fill="none"
                  xmlns="http://www.w3.org/2000/svg"
                >
                  <path
                    fillRule="evenodd"
                    clipRule="evenodd"
                    d="M6.55189 0.333435H17.4369C21.4036 0.333435 23.6669 2.57343 23.6669 6.55177V17.4484C23.6669 21.4034 21.4152 23.6668 17.4486 23.6668H6.55189C2.57356 23.6668 0.333557 21.4034 0.333557 17.4484V6.55177C0.333557 2.57343 2.57356 0.333435 6.55189 0.333435ZM12.9569 12.9684H16.2702C16.8069 12.9568 17.2386 12.5251 17.2386 11.9884C17.2386 11.4518 16.8069 11.0201 16.2702 11.0201H12.9569V7.7301C12.9569 7.19344 12.5252 6.76177 11.9886 6.76177C11.4519 6.76177 11.0202 7.19344 11.0202 7.7301V11.0201H7.71856C7.46189 11.0201 7.21689 11.1251 7.03022 11.3001C6.85522 11.4868 6.75022 11.7306 6.75022 11.9884C6.75022 12.5251 7.18189 12.9568 7.71856 12.9684H11.0202V16.2701C11.0202 16.8068 11.4519 17.2384 11.9886 17.2384C12.5252 17.2384 12.9569 16.8068 12.9569 16.2701V12.9684Z"
                    fill="white"
                  />
                </svg>
                Connect your wallet first
              </Button>
            ) : (
              <Link
                href={`/agents/create`}
                className={cn(
                  buttonVariants({ variant: "default" }),
                  "w-full sm:w-auto text-background flex gap-2"
                )}
              >
                <svg
                  width="24"
                  height="24"
                  viewBox="0 0 24 24"
                  fill="none"
                  xmlns="http://www.w3.org/2000/svg"
                >
                  <path
                    fillRule="evenodd"
                    clipRule="evenodd"
                    d="M6.55189 0.333435H17.4369C21.4036 0.333435 23.6669 2.57343 23.6669 6.55177V17.4484C23.6669 21.4034 21.4152 23.6668 17.4486 23.6668H6.55189C2.57356 23.6668 0.333557 21.4034 0.333557 17.4484V6.55177C0.333557 2.57343 2.57356 0.333435 6.55189 0.333435ZM12.9569 12.9684H16.2702C16.8069 12.9568 17.2386 12.5251 17.2386 11.9884C17.2386 11.4518 16.8069 11.0201 16.2702 11.0201H12.9569V7.7301C12.9569 7.19344 12.5252 6.76177 11.9886 6.76177C11.4519 6.76177 11.0202 7.19344 11.0202 7.7301V11.0201H7.71856C7.46189 11.0201 7.21689 11.1251 7.03022 11.3001C6.85522 11.4868 6.75022 11.7306 6.75022 11.9884C6.75022 12.5251 7.18189 12.9568 7.71856 12.9684H11.0202V16.2701C11.0202 16.8068 11.4519 17.2384 11.9886 17.2384C12.5252 17.2384 12.9569 16.8068 12.9569 16.2701V12.9684Z"
                    fill="white"
                  />
                </svg>
                Create new Agent
              </Link>
            )}
          </>
        )}
        <Link
          href="/agents"
          className={cn(
            buttonVariants({ variant: "outline" }),
            "w-full sm:w-auto flex gap-2"
          )}
        >
          <svg
            width="26"
            height="20"
            viewBox="0 0 26 20"
            fill="none"
            xmlns="http://www.w3.org/2000/svg"
          >
            <path
              d="M24.9459 12.6141V12.6031C24.9441 12.5949 24.9415 12.5869 24.9383 12.5791C24.8657 12.381 24.7813 12.1874 24.6856 11.9994L20.1389 1.66563C20.0951 1.56609 20.0332 1.47559 19.9563 1.39875C19.6312 1.07366 19.2454 0.815782 18.8207 0.63984C18.396 0.463899 17.9408 0.373342 17.4811 0.373342C17.0214 0.373342 16.5662 0.463899 16.1415 0.63984C15.7168 0.815782 15.331 1.07366 15.0059 1.39875C14.8424 1.56245 14.7504 1.78425 14.75 2.01563V4.75H11.25V2.01563C11.2501 1.90069 11.2275 1.78685 11.1836 1.68063C11.1397 1.57441 11.0753 1.47788 10.9941 1.39656C10.6691 1.07147 10.2832 0.813594 9.85849 0.637653C9.4338 0.461711 8.97861 0.371155 8.51892 0.371155C8.05922 0.371155 7.60403 0.461711 7.17934 0.637653C6.75465 0.813594 6.36878 1.07147 6.04376 1.39656C5.96682 1.4734 5.90488 1.5639 5.8611 1.66344L1.31876 11.9994C1.22308 12.1874 1.13871 12.381 1.0661 12.5791C1.06306 12.5865 1.0605 12.5942 1.05845 12.602C1.05845 12.602 1.05845 12.6108 1.05845 12.6141C0.606717 13.9193 0.687536 15.35 1.28339 16.596C1.87924 17.8421 2.94213 18.8031 4.24169 19.2709C5.54126 19.7386 6.97281 19.6754 8.2261 19.095C9.4794 18.5145 10.4535 17.4636 10.9372 16.1698C11.1502 15.5887 11.2576 14.9742 11.2544 14.3553V6.5H14.7544V14.3564C14.7512 14.9753 14.8586 15.5898 15.0716 16.1709C15.5553 17.4646 16.5294 18.5156 17.7827 19.0961C19.036 19.6765 20.4675 19.7397 21.7671 19.272C23.0666 18.8042 24.1295 17.8432 24.7254 16.5971C25.3212 15.3511 25.4021 13.9204 24.9503 12.6152L24.9459 12.6141ZM9.28892 15.5672C8.96581 16.4293 8.31599 17.1294 7.48028 17.5158C6.64457 17.9022 5.69027 17.9437 4.82417 17.6313C3.95806 17.319 3.24991 16.678 2.85316 15.8471C2.45641 15.0163 2.40301 14.0626 2.70454 13.1927L2.90251 12.7409C3.26637 12.0493 3.85125 11.4993 4.56394 11.1787C5.27664 10.858 6.07616 10.7851 6.8351 10.9716C7.59404 11.158 8.26874 11.5931 8.7517 12.2076C9.23466 12.822 9.49809 13.5804 9.50001 14.3619V14.375C9.49995 14.7831 9.4285 15.1881 9.28892 15.5716V15.5672ZM21.2031 17.6639C20.6741 17.8576 20.1061 17.9207 19.5474 17.8478C18.9888 17.775 18.4559 17.5683 17.9942 17.2454C17.5325 16.9226 17.1556 16.493 16.8955 15.9933C16.6353 15.4935 16.4997 14.9384 16.5 14.375V14.363C16.5029 13.5818 16.767 12.8241 17.2503 12.2104C17.7336 11.5968 18.4083 11.1624 19.167 10.9765C19.9257 10.7906 20.7248 10.8638 21.4371 11.1846C22.1493 11.5053 22.7338 12.0551 23.0975 12.7464L23.2955 13.1981C23.6067 14.068 23.5614 15.0256 23.1694 15.8621C22.7775 16.6987 22.0707 17.3464 21.2031 17.6639Z"
              fill="#222222"
            />
          </svg>
          Explore Agents
        </Link>
      </motion.div>
    </>
  );
}

function HeroMarquee() {
  return (
    <div className="relative overflow-hidden bg-[#D7D7D7B2] bg-opacity-70">
      <Marquee pauseOnHover className="[--duration:20s]">
        {[...Array(5)].map((review, idx) => (
          <div key={idx} className="flex items-center">
            <Image
              src="/marquee-dot.png"
              height={45}
              width={45}
              alt=""
              className="mr-2"
            />
            <p className={spaceGrotesk.className}>
              Available for all major programming languages
            </p>
          </div>
        ))}
      </Marquee>
    </div>
  );
}

export function Hero() {
  const privyAuth = usePrivy();

  return (
    <section id="hero" className="">
      <div className="pt-8 px-3 sm:px-6 layout flex flex-col justify-center items-center border-x">
        <HeroPill />
        <HeroTitles />
        <HeroCTA privyAuth={privyAuth} />
      </div>
      <HeroMarquee />
    </section>
  );
}
